@@ -12,11 +12,15 @@ class OSXPlatform(unix.UnixPlatform):
     @property
     def generator_installation_help(self):
         """Return message guiding the user for installing a valid toolchain."""
-        return textwrap.dedent(
-            """
+        return (
+            textwrap.dedent(
+                """
             Building MacOSX wheels for Python {pyver} requires XCode.
             Get it here:
 
               https://developer.apple.com/xcode/
             """
-        ).format(pyver="%s.%s" % sys.version_info[:2]).strip()
+            )
+            .format(pyver="%s.%s" % sys.version_info[:2])
+            .strip()
+        )
