@@ -1,12 +1,9 @@
 """This modules implements the logic allowing to instantiate the expected
 :class:`.abstract.CMakePlatform`."""
 
-import platform
+# pylint: disable=import-outside-toplevel
 
-from . import bsd
-from . import linux
-from . import osx
-from . import windows
+import platform
 
 
 def get_platform():
@@ -15,15 +12,24 @@ def get_platform():
     this_platform = platform.system().lower()
 
     if this_platform == "windows":
+        from . import windows
+
         return windows.WindowsPlatform()
+
     if this_platform == "linux":
+        from . import linux
+
         return linux.LinuxPlatform()
-    elif this_platform == "freebsd":
-        return bsd.BSDPlatform()
-    elif this_platform == "darwin":
+
+    if this_platform == "darwin":
+        from . import osx
+
         return osx.OSXPlatform()
-    elif this_platform == "os400":
+
+    if this_platform in {"freebsd", "os400", "openbsd"}:
+        from . import bsd
+
         return bsd.BSDPlatform()
-    else:
-        raise RuntimeError("Unsupported platform: {:s}. Please contact "
-                           "the scikit-build team.".format(this_platform))
+
+    msg = "Unsupported platform: {:s}. Please contact the scikit-build team.".format(this_platform)
+    raise RuntimeError(msg)
